@@ -1,4 +1,5 @@
-class JsRoutesSprocketsExtension
+class JsRoutes
+class SprocketsExtension
   def initialize(filename, &block)
     @filename = filename
     @source   = block.call
@@ -30,46 +31,32 @@ end
 class Engine < ::Rails::Engine
   require 'sprockets/version'
   v2                = Gem::Dependency.new('', ' ~> 2')
-  v3                = Gem::Dependency.new('', ' >= 3' ,' < 3.7')
-  v37                = Gem::Dependency.new('', ' >= 3.7')
+  vgte3             = Gem::Dependency.new('', ' >= 3')
   sprockets_version = Gem::Version.new(::Sprockets::VERSION).release
   initializer_args  = case sprockets_version
                         when -> (v) { v2.match?('', v) }
                           { after: "sprockets.environment" }
-                        when -> (v) { v3.match?('', v) || v37.match?('', v) }
+                        when -> (v) { vgte3.match?('', v) }
                           { after: :engines_blank_point, before: :finisher_hook }
                         else
                           raise StandardError, "Sprockets version #{sprockets_version} is not supported"
                       end
 
-  is_running_rails = defined?(Rails) && Rails.respond_to?(:version)
-  is_running_rails_32 = is_running_rails && Rails.version.match(/3\.2/)
-
   initializer 'js-routes.dependent_on_routes', initializer_args do
     case sprockets_version
       when  -> (v) { v2.match?('', v) },
-            -> (v) { v3.match?('', v) },
-            -> (v) { v37.match?('', v) }
+            -> (v) { vgte3.match?('', v) }
 
-      # It seems rails 3.2 is not working if
-      # `Rails.application.config.assets.configure` is used for
-      # registering preprocessor
-      if is_running_rails_32
-        Rails.application.assets.register_preprocessor(
+      # Other rails version, assumed newer
+      Rails.application.config.assets.configure do |config|
+        config.register_preprocessor(
           "application/javascript",
-          JsRoutesSprocketsExtension,
+          SprocketsExtension,
         )
-      else
-        # Other rails version, assumed newer
-        Rails.application.config.assets.configure do |config|
-          config.register_preprocessor(
-            "application/javascript",
-            JsRoutesSprocketsExtension,
-          )
-        end
       end
     else
       raise StandardError, "Sprockets version #{sprockets_version} is not supported"
     end
   end
 end
+end
