@@ -14,15 +14,28 @@ describe JsRoutes, "compatibility with Rails"  do
     expect(evaljs("Routes.inbox_path(1)")).to eq(test_routes.inbox_path(1))
   end
 
-  it "should raise error if required argument is not passed" do
+  it "should raise error if required argument is not passed", :aggregate_failures do
     expect { evaljs("Routes.thing_path()") }
-      .to raise_error('Route parameter missing: id')
+      .to raise_error(/Route parameter missing: id/)
     expect { evaljs("Routes.search_path()") }
-      .to raise_error('Route parameter missing: q')
+      .to raise_error(/Route parameter missing: q/)
     expect { evaljs("Routes.book_path()") }
-      .to raise_error('Route parameter missing: title')
+      .to raise_error(/Route parameter missing: title/)
     expect { evaljs("Routes.book_title_path()") }
-      .to raise_error('Route parameter missing: title')
+      .to raise_error(/Route parameter missing: title/)
+  end
+
+  it "should produce error stacktraces including function names" do
+     stacktrace = evaljs("
+        (function(){
+          try {
+            Routes.thing_path()
+          } catch(e) {
+            return e.stack;
+          }
+        })()
+      ")
+    expect(stacktrace).to include "thing_path"
   end
 
   it "should support 0 as a member parameter" do
@@ -57,6 +70,10 @@ describe JsRoutes, "compatibility with Rails"  do
     expect(evaljs("Routes.inbox_path(1, {expanded: true, anchor: 'hello'})")).to eq(test_routes.inbox_path(1, :expanded => true, :anchor => "hello"))
   end
 
+  it "should support required paramters given as options hash" do
+    expect(evaljs("Routes.search_path({q: 'hello'})")).to eq(test_routes.search_path(:q => 'hello'))
+  end
+
   it "should use irregular ActiveSupport pluralizations" do
     expect(evaljs("Routes.budgies_path()")).to eq(test_routes.budgies_path)
     expect(evaljs("Routes.budgie_path(1)")).to eq(test_routes.budgie_path(1))
@@ -64,6 +81,16 @@ describe JsRoutes, "compatibility with Rails"  do
     expect(evaljs("Routes.budgie_descendents_path(1)")).to eq(test_routes.budgie_descendents_path(1))
   end
 
+  it "should support route with parameters containing symbols that need URI-encoding", :aggregate_failures do
+    expect(evaljs("Routes.inbox_path('#hello')")).to eq(test_routes.inbox_path('#hello'))
+    expect(evaljs("Routes.inbox_path('some param')")).to eq(test_routes.inbox_path('some param'))
+    expect(evaljs("Routes.inbox_path('some param with more & more encode symbols')")).to eq(test_routes.inbox_path('some param with more & more encode symbols'))
+  end
+  it "should support route with parameters containing symbols not need URI-encoding", :aggregate_failures do
+    expect(evaljs("Routes.inbox_path(':some_id')")).to eq(test_routes.inbox_path(':some_id'))
+    expect(evaljs("Routes.inbox_path('.+')")).to eq(test_routes.inbox_path('.+'))
+  end
+
   describe "when route has defaults" do
     it "should support route default format" do
       expect(evaljs("Routes.api_purchases_path()")).to eq(test_routes.api_purchases_path)
@@ -145,6 +172,9 @@ describe JsRoutes, "compatibility with Rails"  do
       expect(evaljs("Routes.inboxes_path({uri: 'http://example.com'})")).to eq(test_routes.inboxes_path(:uri => 'http://example.com'))
     end
 
+    it "should support nested object null parameters" do
+      expect(evaljs("Routes.inboxes_path({hello: {world: null}})")).to eq(test_routes.inboxes_path(:hello => {:world => nil}))
+    end
   end
 
 
@@ -157,14 +187,18 @@ describe JsRoutes, "compatibility with Rails"  do
       expect(evaljs("Routes.book_path(['thrillers'], 1)")).to eq(test_routes.book_path(['thrillers'], 1))
     end
 
-    it "should bee support routes globbing as array" do
+    it "should support routes globbing as array" do
       expect(evaljs("Routes.book_path([1, 2, 3], 1)")).to eq(test_routes.book_path([1, 2, 3], 1))
     end
 
-    it "should bee support routes globbing as hash" do
+    it "should support routes globbing with slash" do
       expect(evaljs("Routes.book_path('a_test/b_test/c_test', 1)")).to eq(test_routes.book_path('a_test/b_test/c_test', 1))
     end
 
+    it "should support routes globbing as hash" do
+      expect(evaljs("Routes.book_path('a%b', 1)")).to eq(test_routes.book_path('a%b', 1))
+    end
+
     it "should support routes globbing as array with optional params" do
       expect(evaljs("Routes.book_path([1, 2, 3, 5], 1, {c: '1'})")).to eq(test_routes.book_path([1, 2, 3, 5], 1, { :c => "1" }))
     end
@@ -176,14 +210,6 @@ describe JsRoutes, "compatibility with Rails"  do
     it "should support routes globbing in book_title route as array with optional params" do
       expect(evaljs("Routes.book_title_path('john', ['thrillers', 'comedian'], {some_key: 'some_value'})")).to eq(test_routes.book_title_path('john', ['thrillers', 'comedian'], {:some_key => 'some_value'}))
     end
-
-    it "should support required paramters given as options hash" do
-      expect(evaljs("Routes.search_path({q: 'hello'})")).to eq(test_routes.search_path(:q => 'hello'))
-    end
-
-    it "should support nested object null parameters" do
-      expect(evaljs("Routes.inboxes_path({hello: {world: null}})")).to eq(test_routes.inboxes_path(:hello => {:world => nil}))
-    end
   end
 
   context "using optional path fragments" do
@@ -209,7 +235,7 @@ describe JsRoutes, "compatibility with Rails"  do
 
       it "should raise error when passing non-full list of arguments and some query params" do
         expect { evaljs("Routes.thing_path(5, {q: 'hello'})") }
-          .to raise_error('Route parameter missing: id')
+          .to raise_error(/Route parameter missing: id/)
       end
 
       it "should treat null as non-given optional part" do
@@ -221,19 +247,13 @@ describe JsRoutes, "compatibility with Rails"  do
       end
 
       it "should skip leading and trailing optional parts" do
-        skip if Rails.version < '4'
         expect(evaljs("Routes.thing_deep_path(1, 2)")).to eq(test_routes.thing_deep_path(1, 2))
       end
     end
 
     context "and including them" do
-      if Rails.version < '4'
-        it "should fail when insufficient arguments are given" do
-          expect { evaljs("Routes.thing_deep_path(1)")}
-            .to raise_error('Route parameter missing: second_required')
-          expect { evaljs("Routes.thing_deep_path(1,2)")}
-            .to raise_error('Route parameter missing: third_required')
-        end
+      it "should fail when insufficient arguments are given" do
+        expect { evaljs("Routes.thing_deep_path(2)") }.to raise_error(/Route parameter missing: third_required/)
       end
 
       it "should include the optional parts" do
@@ -245,6 +265,7 @@ describe JsRoutes, "compatibility with Rails"  do
         expect(evaljs("Routes.thing_deep_path(3, { first_optional: 1, second_required: 2 })")).to eq(test_routes.thing_deep_path(3, first_optional: 1, second_required: 2))
         expect(evaljs("Routes.thing_deep_path(3, { first_optional: 1, second_required: 2, forth_optional: 4 })")).to eq(test_routes.thing_deep_path(3, first_optional: 1, second_required: 2, forth_optional: 4))
         expect(evaljs("Routes.thing_deep_path(4, { first_optional: 1, second_required: 2, third_required: 3 })")).to eq(test_routes.thing_deep_path(4, first_optional: 1, second_required: 2, third_required: 3))
+        expect(evaljs("Routes.thing_deep_path(2, 3)")).to eq(test_routes.thing_deep_path(2, 3))
         expect(evaljs("Routes.thing_deep_path(1, 2, { third_required: 3 })")).to eq(test_routes.thing_deep_path(1, 2, third_required: 3))
         expect(evaljs("Routes.thing_deep_path(1,2, {third_required: 3, q: 'bogdan'})")).to eq(test_routes.thing_deep_path(1,2, {third_required: 3, q: 'bogdan'}))
         expect(evaljs("Routes.thing_deep_path(1, 2, { forth_optional: 4, third_required: 3 })")).to eq(test_routes.thing_deep_path(1, 2, forth_optional: 4, third_required: 3))
