@@ -43,6 +43,21 @@ describe "after Rails initialization" do
     expect(File.exists?(NAME)).to be_truthy
   end
 
+  it "should not rewrite routes file if nothing changed" do
+    routes_file_mtime = File.mtime(NAME)
+    JsRoutes.generate!(NAME)
+    expect(File.mtime(NAME)).to eq(routes_file_mtime)
+  end
+
+  it "should rewrite routes file if file content changed" do
+    # Change content of existed routes file (add space to the end of file).
+    File.open(NAME, 'a') { |f| f << ' ' }
+    routes_file_mtime = File.mtime(NAME)
+    sleep(1)
+    JsRoutes.generate!(NAME)
+    expect(File.mtime(NAME)).not_to eq(routes_file_mtime)
+  end
+
   context "JsRoutes::Engine" do
     TEST_ASSET_PATH = Rails.root.join('app','assets','javascripts','test.js')
 
@@ -78,7 +93,7 @@ describe "after Rails initialization" do
               Rails.application.config.assets.initialize_on_precompile = true
             end
             it "should render some javascript" do
-              expect(evaluate(ctx, 'js-routes.js')).to match(/root\.Routes/)
+              expect(evaluate(ctx, 'js-routes.js')).to match(/routes = /)
             end
           end
           context "and not initialize on precompile" do
@@ -86,11 +101,7 @@ describe "after Rails initialization" do
               Rails.application.config.assets.initialize_on_precompile = false
             end
             it "should raise an exception if 3 version" do
-              if 3 == Rails::VERSION::MAJOR
-                expect { evaluate(ctx, 'js-routes.js') }.to raise_error(/Cannot precompile/)
-              else
-                expect(evaluate(ctx, 'js-routes.js')).to match(/root\.Routes/)
-              end
+              expect(evaluate(ctx, 'js-routes.js')).to match(/routes = /)
             end
           end
 
